==> hiki-0.8.0.tar.gz: hiki-0.8.0/plugin/ja/00default.rb <==
#
# preferences (resources)
#
add_conf_proc( 'default', '' ) do
  saveconf_default
  <<-HTML
      <h3 class="subtitle">̾</h3>
      <p>̾ꤷޤ</p>
      <p><input name="site_name" value="#{CGI::escapeHTML(@conf.site_name)}" size="40"></p>
      <h3 class="subtitle">̾</h3>
      <p>ʤ̾ꤷޤ</p>
      <p><input name="author_name" value="#{CGI::escapeHTML(@conf.author_name)}" size="40"></p>
      <h3 class="subtitle">᡼륢ɥ쥹</h3>
      <p>ʤΥ᡼륢ɥ쥹ꤷޤ</p>
      <p><input name="mail" value="#{CGI::escapeHTML(@conf.mail)}" size="40"></p>
      <h3 class="subtitle">᡼</h3>
      <p>ڡιä˥᡼Τ뤫ɤꤷޤ᡼ϴǻꤷɥ쥹ޤ餫hikiconf.rbSMTPФꤷƤƤ</p>
      <p><select name="mail_on_update">
         <option value="true"#{@conf.mail_on_update ? ' selected' : ''}>᡼ </option>
         <option value="false"#{@conf.mail_on_update ? '' : ' selected'}></option>
         </select></p>
  HTML
end

add_conf_proc( 'password', 'ѥ' ) do
  '<h3 class="password">ѥ</h3>' +
    case saveconf_password
    when :password_change_success
      '<p>ѥѥɤѹޤ</p>'
    when :password_change_failure
      '<p>ѥѥɤְäƤ뤫ѥɤפޤ</p>'
    when nil
      '<p>ѥѥɤѹޤ</p>'
    end +
    <<-HTML
        <p>ߤΥѥ: <input type="password" name="old_password" size="40"></p>
        <p>ѥ: <input type="password" name="password1" size="40"></p>
        <p>ѥɡʳǧѤ˺ϤƤ: <input type="password" name="password2" size="40"></p>
    HTML
end

add_conf_proc( 'theme', 'ɽ' ) do
  saveconf_theme
  r = <<-HTML
      <h3 class="subtitle">ơޤλ</h3>
      <p>ɽ˻Ѥơޤ򤹤뤳ȤǤޤ</p>
      <p><select name="theme">
  HTML
  @conf_theme_list.each do |theme|
    r << %Q|<option value="#{theme[0]}"#{if theme[0] == @conf.theme then " selected" end}>#{theme[1]}</option>|
  end
  r << <<-HTML
      </select></p>
      <h3 class="subtitle">ơURLλ</h3>
      <p>ơޤURLꤹ뤳ȤǤޤľCSSꤷ硢Ρ֥ơޤλפ򤷤ơޤ̵뤵졢ꤷCSSȤޤ</p>
      <p><input name="theme_url" value="#{CGI::escapeHTML(@conf.theme_url)}" size="60"></p>
      <h3 class="subtitle">ơޥǥ쥯ȥλ</h3>
      <p>ơޤǥ쥯ȥꤹ뤳ȤǤޤʣֻ˻ѡ</p>
      <p><input name="theme_path" value="#{CGI::escapeHTML(@conf.theme_path)}" size="60"></p>
      <h3 class="subtitle">ɥС</h3>
      <p>ơޤˤäƤϥɥСѤɽΤޤξ硢ɥСɽ򥪥դˤ뤳ȤǤޤ</p>
      <p><select name="sidebar">
         <option value="true"#{@conf.use_sidebar ? ' selected' : ''}>Ѥ</option>
         <option value="false"#{@conf.use_sidebar ? '' : ' selected'}>Ѥʤ</option>
         </select></p>
      <h3 class="subtitle">ᥤ󥨥ꥢΥ饹̾(CSS)λ</h3>
      <p>ǥեȤǤʸʬΥ饹̾Ȥ'main'ѤޤʳΥ饹̾Ѥ˻ꤷޤ</p>
      <p><input name="main_class" value="#{CGI::escapeHTML(@conf.main_class)}" size="20"></p>
      <h3 class="subtitle">ɥСΥ饹̾(CSS)λ</h3>
      <p>ǥեȤǤϥɥСΥ饹̾Ȥ'sidebar'ѤޤʳΥ饹̾Ѥ˻ꤷޤ</p>
      <p><input name="sidebar_class" value="#{CGI::escapeHTML(@conf.sidebar_class)}" size="20"></p>
      <h3 class="subtitle">ȥ󥯤</h3>
      <p>¸Υڡ˼ưŪ˥󥯤ꤹ륪ȥ󥯵ǽѤ뤫ɤꤷޤ</p>
      <p><select name="auto_link">
         <option value="true"#{@conf.auto_link ? ' selected' : ''}>Ѥ</option>
         <option value="false"#{@conf.auto_link ? '' : ' selected'}>Ѥʤ</option>
         </select></p>
      <h3 class="subtitle">WikiName ˤ󥯵ǽ</h3>
      <p>WikiName ˤ󥯵ǽѤ뤫ɤꤷޤ</p>
      <p><select name="use_wikiname">
         <option value="true"#{@conf.use_wikiname ? ' selected' : ''}>Ѥ</option>
         <option value="false"#{@conf.use_wikiname ? '' : ' selected'}>Ѥʤ</option>
         </select></p>
  HTML
end

==> hiki-0.8.4.tar.gz: hiki-0.8.4/plugin/ja/00default.rb <==
#
# preferences (resources)
#
add_conf_proc( 'default', '' ) do
  saveconf_default
  <<-HTML
      <h3 class="subtitle">̾</h3>
      <p>̾ꤷޤ</p>
      <p><input name="site_name" value="#{CGI::escapeHTML(@conf.site_name)}" size="40"></p>
      <h3 class="subtitle">̾</h3>
      <p>ʤ̾ꤷޤ</p>
      <p><input name="author_name" value="#{CGI::escapeHTML(@conf.author_name)}" size="40"></p>
      <h3 class="subtitle">᡼륢ɥ쥹</h3>
      <p>ʤΥ᡼륢ɥ쥹ꤷޤ</p>
      <p><input name="mail" value="#{CGI::escapeHTML(@conf.mail)}" size="40"></p>
      <h3 class="subtitle">᡼</h3>
      <p>ڡιä˥᡼Τ뤫ɤꤷޤ᡼ϴǻꤷɥ쥹ޤ餫hikiconf.rbSMTPФꤷƤƤ</p>
      <p><select name="mail_on_update">
         <option value="true"#{@conf.mail_on_update ? ' selected' : ''}>᡼ </option>
         <option value="false"#{@conf.mail_on_update ? '' : ' selected'}></option>
         </select></p>
  HTML
end

add_conf_proc( 'password', 'ѥ' ) do
  '<h3 class="password">ѥ</h3>' +
    case saveconf_password
    when :password_change_success
      '<p>ѥѥɤѹޤ</p>'
    when :password_change_failure
      '<p>ѥѥɤְäƤ뤫ѥɤפޤ</p>'
    when nil
      '<p>ѥѥɤѹޤ</p>'
    end +
    <<-HTML
        <p>ߤΥѥ: <input type="password" name="old_password" size="40"></p>
        <p>ѥ: <input type="password" name="password1" size="40"></p>
        <p>ѥɡʳǧѤ˺ϤƤ: <input type="password" name="password2" size="40"></p>
    HTML
end

add_conf_proc( 'theme', 'ɽ' ) do
  saveconf_theme
  r = <<-HTML
      <h3 class="subtitle">ơޤλ</h3>
      <p>ɽ˻Ѥơޤ򤹤뤳ȤǤޤ</p>
      <p><select name="theme">
  HTML
  @conf_theme_list.each do |theme|
    r << %Q|<option value="#{theme[0]}"#{if theme[0] == @conf.theme then " selected" end}>#{theme[1]}</option>|
  end
  r << <<-HTML
      </select></p>
      <h3 class="subtitle">ơURLλ</h3>
      <p>ơޤURLꤹ뤳ȤǤޤľCSSꤷ硢Ρ֥ơޤλפ򤷤ơޤ̵뤵졢ꤷCSSȤޤ</p>
      <p><input name="theme_url" value="#{CGI::escapeHTML(@conf.theme_url)}" size="60"></p>
      <h3 class="subtitle">ơޥǥ쥯ȥλ</h3>
      <p>ơޤǥ쥯ȥꤹ뤳ȤǤޤʣֻ˻ѡ</p>
      <p><input name="theme_path" value="#{CGI::escapeHTML(@conf.theme_path)}" size="60"></p>
      <h3 class="subtitle">ɥС</h3>
      <p>ơޤˤäƤϥɥСѤɽΤޤξ硢ɥСɽ򥪥դˤ뤳ȤǤޤ</p>
      <p><select name="sidebar">
         <option value="true"#{@conf.use_sidebar ? ' selected' : ''}>Ѥ</option>
         <option value="false"#{@conf.use_sidebar ? '' : ' selected'}>Ѥʤ</option>
         </select></p>
      <h3 class="subtitle">ᥤ󥨥ꥢΥ饹̾(CSS)λ</h3>
      <p>ǥեȤǤʸʬΥ饹̾Ȥ'main'ѤޤʳΥ饹̾Ѥ˻ꤷޤ</p>
      <p><input name="main_class" value="#{CGI::escapeHTML(@conf.main_class)}" size="20"></p>
      <h3 class="subtitle">ɥСΥ饹̾(CSS)λ</h3>
      <p>ǥեȤǤϥɥСΥ饹̾Ȥ'sidebar'ѤޤʳΥ饹̾Ѥ˻ꤷޤ</p>
      <p><input name="sidebar_class" value="#{CGI::escapeHTML(@conf.sidebar_class)}" size="20"></p>
      <h3 class="subtitle">ȥ󥯤</h3>
      <p>¸Υڡ˼ưŪ˥󥯤ꤹ륪ȥ󥯵ǽѤ뤫ɤꤷޤ</p>
      <p><select name="auto_link">
         <option value="true"#{@conf.auto_link ? ' selected' : ''}>Ѥ</option>
         <option value="false"#{@conf.auto_link ? '' : ' selected'}>Ѥʤ</option>
         </select></p>
      <h3 class="subtitle">WikiName ˤ󥯵ǽ</h3>
      <p>WikiName ˤ󥯵ǽѤ뤫ɤꤷޤ</p>
      <p><select name="use_wikiname">
         <option value="true"#{@conf.use_wikiname ? ' selected' : ''}>Ѥ</option>
         <option value="false"#{@conf.use_wikiname ? '' : ' selected'}>Ѥʤ</option>
         </select></p>
  HTML
end

add_conf_proc( 'xmlrpc', 'XML-RPC' ) do
  saveconf_xmlrpc

  <<-HTML
      <h3 class="subtitle">XML-RPC</h3>
      <p>XML-RPC 󥿥եͭˤ뤫ɤꤷޤ</p>
      <p><select name="xmlrpc_enabled">
         <option value="true"#{@conf.xmlrpc_enabled ? ' selected' : ''}>ͭ</option>
         <option value="false"#{@conf.xmlrpc_enabled ? '' : ' selected'}>̵</option>
         </select></p>
  HTML
end
